import os
import sys
import unittest

import numpy as np

from extended_train_test_split.interfaces import train_test_split_molecules


class Test_molecules_interface(unittest.TestCase):
    """
    Test the various functionalities of molecules_interface.
    """

    @classmethod
    def setUpClass(self):
        return

    def test_molecules_interface(self):
        """
        """
        return


if __name__ == '__main__':
    unittest.main()
