import os
import sys
import unittest

import numpy as np

from extended_train_test_split.samplers import kennard_stone


class Test_kennard_stone(unittest.TestCase):
    """
    Test the various functionalities of kennard_stone.
    """

    @classmethod
    def setUpClass(self):
        return

    def test_kennard_stone(self):
        """
        """
        return


if __name__ == '__main__':
    unittest.main()
